@@ -29,11 +29,10 @@ solve.QP.compact <- function(Dmat, dvec, Amat, Aind, bvec, meq=0,
     stop("Dmat and dvec are incompatible!")
   if( (anrow+1 != nrow(Aind)) || (q != ncol(Aind)) || (q != length(bvec)) )
     stop("Amat, Aind and bvec are incompatible!")
-  Aindok <- .Fortran("aind",
+  Aindok <- .Fortran(.QP_aind,
                      as.integer(Aind), as.integer(anrow+1),
                      as.integer(q), as.integer(n),
-                     ok=as.logical(TRUE),
-                     PACKAGE = "quadprog")$ok
+                     ok=TRUE)$ok
   if( !Aindok )
     stop("Aind contains illegal indexes!")
   if( (meq > q) || (meq < 0 ) )
@@ -48,7 +47,7 @@ solve.QP.compact <- function(Dmat, dvec, Amat, Aind, bvec, meq=0,
   work  <- rep(0,2*n+r*(r+5)/2+2*q+1)
   iter  <- rep(0,2)
 
-  res1 <- .Fortran("qpgen1",
+  res1 <- .Fortran(.QP_qpgen1,
                    as.double(Dmat), dvec=as.double(dvec),
                    as.integer(n), as.integer(n),
                    sol=as.double(sol), lagr=as.double(lagr),
@@ -57,8 +56,7 @@ solve.QP.compact <- function(Dmat, dvec, Amat, Aind, bvec, meq=0,
                    as.integer(anrow), as.integer(q), as.integer(meq),
                    iact=as.integer(iact), nact=as.integer(nact),
                    iter=as.integer(iter), 
-                   work=as.double(work), ierr=as.integer(factorized),
-                   PACKAGE = "quadprog")
+                   work=as.double(work), ierr=as.integer(factorized))
 
   if( res1$ierr == 1)
     stop("constraints are inconsistent, no solution!")
@@ -116,7 +114,7 @@ solve.QP <- function(Dmat, dvec, Amat, bvec, meq=0, factorized=FALSE){
   work  <- rep(0,2*n+r*(r+5)/2+2*q+1)
   iter  <- rep(0,2)
 
-  res1 <- .Fortran("qpgen2",
+  res1 <- .Fortran(.QP_qpgen2,
                    as.double(Dmat), dvec=as.double(dvec),
                    as.integer(n), as.integer(n),
                    sol=as.double(sol), lagr=as.double(lagr),
@@ -125,8 +123,7 @@ solve.QP <- function(Dmat, dvec, Amat, bvec, meq=0, factorized=FALSE){
                    as.integer(q), as.integer(meq),
                    iact=as.integer(iact), nact=as.integer(nact),
                    iter=as.integer(iter), work=as.double(work),
-                   ierr=as.integer(factorized),
-                   PACKAGE = "quadprog")
+                   ierr=as.integer(factorized))
 
   if( res1$ierr == 1)
     stop("constraints are inconsistent, no solution!")
